@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: reducers
 version: 3.12.1
-id: reducers-3.12.1-ea06090a8c66812eff0cd7d6cba6d6c9
-key: reduc_EOxQ1EVuExVG88ZTGY6pK1
+id: reducers-3.12.1-9c0679f8e3a7104b42907174b9bc86fd
+key: reduc_2CjdjSKgYE7F5HQsUt2i9P
 license: BSD3
 copyright: Copyright (C) 2008-2013 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,7 +26,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/reducers-3.12.1
-hs-libraries: HSreducers-3.12.1-EOxQ1EVuExVG88ZTGY6pK1
+hs-libraries: HSreducers-3.12.1-2CjdjSKgYE7F5HQsUt2i9P
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -34,11 +34,11 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    semigroupoids-5.0.1-e4734876ceb621b0eefb491ac209dad3
-    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
+    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
+    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
 haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
 haddock-html: /usr/share/doc/haskell-reducers/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
